@@ -17,11 +17,24 @@ literals = '[,]'
 # Lexer
 
 t_ignore = ' \t'
-t_KEY = r'[a-zA-Z_][a-zA-Z0-9_]*'
+
+def t_comment(t):
+    r'\#.*'
+    pass
+
+def t_newline(t):
+    r'\n+'
+    t.lexer.lineno += len(t.value)
+
+def t_error(t):
+    print "Illegal character '%s'" % t.value[0]
+    t.lexer.skip(1)
+
+t_KEY = r'[a-zA-Z_][a-zA-Z0-9_#\?]*'
 t_EQUALS = r'='
 
 def t_KEYGROUP(t):
-    r'\[[a-zA-Z_][a-zA-Z0-9_\.]*\]'
+    r'\[[a-zA-Z_][a-zA-Z0-9_#\?\.]*\]'
     t.value = t.value[1:-1].split('.')
     return t
 
@@ -47,18 +60,6 @@ def t_INTEGER(t):
     t.value = int(t.value)
     return t
 
-def t_comment(t):
-    r'\#.*'
-    pass
-
-def t_newline(t):
-    r'\n+'
-    t.lexer.lineno += len(t.value)
-
-def t_error(t):
-    print "Illegal character '%s'" % t.value[0]
-    t.lexer.skip(1)
-
 lex.lex()
 
 
@@ -81,8 +82,11 @@ class TOMLParser(object):
 
     def p_assign(self, p):
         '''assign : KEY EQUALS value
-                  | assign KEYGROUP'''
-        if isinstance(p[2], list):
+                  | assign KEYGROUP
+                  | KEYGROUP'''
+        if isinstance(p[1], list):
+            self.keys = p[1]
+        elif isinstance(p[2], list):
             self.keys = p[2]
         else:
             d = self.mapping
